summaryrefslogtreecommitdiffstats
path: root/tdecore/kiconloader.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 13:28:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 13:28:26 -0600
commitd3afa6baf98ef5ac191996cc9b909ff9074c168c (patch)
treea1e1247371cd17715f83036a3664755206ab9ba2 /tdecore/kiconloader.h
parent12f3d421cd2991c0e3f96994efb836ce244172ff (diff)
downloadtdelibs-d3afa6baf98ef5ac191996cc9b909ff9074c168c.tar.gz
tdelibs-d3afa6baf98ef5ac191996cc9b909ff9074c168c.zip
Rename KStandard for enhanced compatibility with KDE4
Diffstat (limited to 'tdecore/kiconloader.h')
-rw-r--r--tdecore/kiconloader.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/kiconloader.h b/tdecore/kiconloader.h
index 2357aef13..86fa77679 100644
--- a/tdecore/kiconloader.h
+++ b/tdecore/kiconloader.h
@@ -35,7 +35,7 @@ struct KIconGroup;
class KIconThemeNode;
class TDEConfig;
struct KIconLoaderPrivate;
-class KStandardDirs;
+class TDEStandardDirs;
class KIconEffect;
@@ -83,7 +83,7 @@ public:
* @param appname Add the data directories of this application to the
* icon search path for the "User" group. The default argument adds the
* directories of the current application.
* @param dirs the KStandardDirs object to use. If null the global one is used
*
* Usually, you use the default iconloader, which can be accessed via
* TDEGlobal::iconLoader(), so you hardly ever have to create an
@@ -92,7 +92,7 @@ public:
* @see TDEGlobal::iconLoader()
* @see TDEInstance::iconLoader()
*/
- KIconLoader(const TQString& appname=TQString::null, KStandardDirs *dirs = 0);
+ KIconLoader(const TQString& appname=TQString::null, TDEStandardDirs *dirs = 0);
/**
* Cleanup
@@ -301,7 +301,7 @@ public:
* @param _dirs the new standard directories. If 0, the directories
* from TDEGlobal will be taken.
*/
- void reconfigure( const TQString& _appname, KStandardDirs *_dirs );
+ void reconfigure( const TQString& _appname, TDEStandardDirs *_dirs );
/**
* Returns the unknown icon. An icon that is used when no other icon
@@ -368,7 +368,7 @@ public:
/**
* @internal
*/
- void init( const TQString& _appname, KStandardDirs *_dirs );
+ void init( const TQString& _appname, TDEStandardDirs *_dirs );
/**
* @internal
@@ -83,7 +83,7 @@ public:
* icon search path for the "User" group. The default argument adds the
* directories of the current application.
- * @param dirs the KStandardDirs object to use. If null the global one is used
+ * @param dirs the TDEStandardDirs object to use. If null the global one is used
*
* Usually, you use the default iconloader, which can be accessed via